General Bullshit - The Something Awful Forums
Description: This is the general discussion forum for discussing things, generally.

Redacted

Subforums
Title - Description | Topics | Posts
--- | --- | ---
Fuck You and Dine - Bring your own bun. | 348 | 40728
SA's Front Page Discussion - All front page-related comments should go in here. | 259 | 9479
Everyone's/Neurotic - E/N, relationship issues, and other self-centered posts regarding your disastrous life go here. | 1693 | 488854

Filter Posts
Remove filter

Threads
| Icon | Title (Pages) | Author | Re | Views | Rating | Killed By
--- | --- | --- | --- | --- | --- | --- | ---
|  | come visit the 25th anniversary forum! celebrate with us! | Pragmatica | - | - | - | 1:00 AM Nov 30, 2024
|  | The GBS Awful Fiction Writing Workshop (56k Okay) | syntaxfunction | 4 | 234 |  | 20:04 Dec 4, 2024 MK-Ultramarathon
|  | SASS 2024: This Time With Spirit Halloween Pages: 1 2 3 4 5 6 | tiaz | 227 | 6652 |  | 21:43 Dec 4, 2024 Soul Dentist
|  | Winterize Movies Pages: 1 2 3 | TIP | 89 | 4052 |  | 21:25 Dec 4, 2024 Gunshow Poophole
|  | Goooooons! Merry Awful Xmas Music Thread 2K24! Pages: 1 2 3 4 5 | Rupert Buttermilk | 182 | 6196 |  | 20:00 Dec 4, 2024 e.pilot
|  | X 77 The USA Goonfund: GOONS NEED MONEY RIGHT NOW Pages: 1 2 3... 14 15 16 Last post | really queer Christmas | 612 | 106162 |  | 09:20 Dec 4, 2024 docbeard
|  | X Be a better posting pal: It's your new GBS rules! | Seth Pecksniff | 0 | 19333 |  | 10:00 Jun 13, 2023 Seth Pecksniff
|  | canada thread - post in this thread every you lol that trump isn't our pres Pages: 1 2 3... 39 40 41 Last post | hot cocoa on the couch | 1617 | 28832 |  | 22:12 Dec 4, 2024 Mister Speaker
|  | X 452 post itt every time you lol that Hunter neverthelessed Pages: 1 2 3... 515 516 517 Last post | Karma Comedian | 20651 | 1146817 |  | 22:12 Dec 4, 2024 twistedmentat
|  | X 33909 the weed thread: if you yopu want o get hungry go for it. Pages: 1 2 3... 849 850 851 Last post | thathonkey | 34028 | 1134627 |  | 22:12 Dec 4, 2024 TEMPLE GRANDIN OS
|  | X 237 OSHA IV: Chett's nuts roasting over an open firework Pages: 1 2 3... 2808 2809 2810 Last post | Nude | 112369 | 14189654 |  | 22:12 Dec 4, 2024 Foxfire_
|  | Unpopular Videogame Opinions: A Midsummer's Night's Dreamcast Pages: 1 2 3... 2767 2768 2769 Last post | Homestar Runner | 110725 | 3755715 |  | 22:10 Dec 4, 2024 credburn
|  | X 4 Elon Musk: My Cybertruck does look awesome on that tow truck! Pages: 1 2 3... 4887 4888 4889 Last post | AARD VARKMAN | 195538 | 17006714 |  | 22:08 Dec 4, 2024 Arn Anderson
|  | X 5540 Official GBS chat thread Pages: 1 2 3... 1400 1401 1402 Last post | hot cocoa on the couch | 56051 | 734537 |  | 22:07 Dec 4, 2024 satanic splash-back
|  | Chinathread: Look at this pig'zhuge balls! Pages: 1 2 3... 729 730 731 Last post | Grand Fromage | 29239 | 2272360 |  | 22:07 Dec 4, 2024 thetoughestbean
|  | What is your religion and why? Pages: 1 2 3 4 5 6 7 | Donglepuss | 262 | 5405 |  | 22:05 Dec 4, 2024 redshirt
|  | I found the roundest bird at work Pages: 1 2 | Shithouse Dave | 55 | 1361 |  | 22:04 Dec 4, 2024 covidstomper58
|  | CEO of UnitedHealthCare Fatally Shot in targeted shooting Pages: 1 2 3... 11 12 13 Last post | ninjoatse.cx | 501 | 22871 |  | 22:02 Dec 4, 2024 My Spirit Otter
|  | War in Ukraine: I receive: Ukraine joins NATO. You receive: USA leaves NATO. Pages: 1 2 3... 1729 1730 1731 Last post | Toxic Mental | 69201 | 6972859 |  | 22:00 Dec 4, 2024 weg
|  | X 2371 Ad blockers are not allowed on YouTube Pages: 1 2 3... 59 60 61 Last post | EorayMel | 2410 | 155840 |  | 21:59 Dec 4, 2024 counterfeitsaint
|  | r/relationships: surrender to the gaycation or be destroyed Pages: 1 2 3... 971 972 973 Last post | Pope Corky the IX | 38882 | 3959467 |  | 21:59 Dec 4, 2024 Hughlander
|  | X 13790 USA: DEATH GUNS MEAT Pages: 1 2 3... 344 345 346 Last post | Waltzing Along | 13829 | 902433 |  | 21:57 Dec 4, 2024 TEMPLE GRANDIN OS
|  | X 200 Cursed Images: Boss makes a dollar, I make a dime. I make a monster on company time Pages: 1 2 3... 786 787 788 Last post | codo27 | 31519 | 3424448 |  | 21:55 Dec 4, 2024 Bonzo
|  | what has your cat done today? Pages: 1 2 3... 141 142 143 Last post | ChubbyChecker | 5680 | 238489 |  | 21:51 Dec 4, 2024 Breetai
|  | X 261 LGBSTQIA+ : puzzles all obtuse and unsolvable unless you know the hanky code Pages: 1 2 3... 123 124 125 Last post | Saint Isaias Boner | 4980 | 199887 |  | 21:49 Dec 4, 2024 Prokhor Zakharov
|  | Whats the most psychotic boomer meltdown youve ever witnessed? Pages: 1 2 3... 24 25 26 Last post | pencilhands | 1008 | 66275 |  | 21:46 Dec 4, 2024 Kingo Ligma
|  | X 37706 Post five words in here. Pages: 1 2 3... 944 945 946 Last post | Geemer | 37825 | 443397 |  | 21:46 Dec 4, 2024 redshirt
|  | X 33772 Dumb shit your work does: Worst case scenario we get the contract Pages: 1 2 3... 848 849 850 Last post | Full Metal Jackass | 33971 | 2676076 |  | 21:44 Dec 4, 2024 ShimaTetsuo
|  | I stepped on a scorpion this morning and it stung me underneath my foot :( Pages: 1 2 | You Are A Werewolf | 54 | 907 |  | 21:44 Dec 4, 2024 Anderson Koopa
|  | AUSGBS: Ahhh fuck its nearly 2025 already Pages: 1 2 3... 1919 1920 1921 Last post | Isaac | 76837 | 1942548 |  | 21:40 Dec 4, 2024 Croccers
|  | X 1798 Red Letter Media 2024: What I have sucked will shock you Pages: 1 2 3... 871 872 873 Last post | reignofevil | 34917 | 1310879 |  | 21:37 Dec 4, 2024 redshirt
|  | X 4522 Bitcoin: Charturbate Pages: 1 2 3... 2314 2315 2316 Last post | Waltzing Along | 92601 | 7364360 |  | 21:37 Dec 4, 2024 smoobles
|  | Name a Vibe Pages: 1 2 3... 6 7 8 Last post | redshirt | 309 | 4974 |  | 21:37 Dec 4, 2024 redshirt
|  | Costco: They're Eating the Dogs Pages: 1 2 3... 485 486 487 Last post | Chinatown | 19454 | 1153549 |  | 21:37 Dec 4, 2024 Verman
|  | X 20087 Post here every time you notice something got shittier for no good reason Pages: 1 2 3... 508 509 510 Last post | AARD VARKMAN | 20366 | 1246191 |  | 21:27 Dec 4, 2024 Duck and Cover
|  | Sit on Robot Santa's Lap Pages: 1 2 3 | snorch | 96 | 1906 |  | 21:19 Dec 4, 2024 snorch
|  | X 3154 Foreign Street Food: a jolly fat twerkish gentleman Pages: 1 2 3... 78 79 80 Last post | AARD VARKMAN | 3193 | 256850 |  | 21:16 Dec 4, 2024 bob dobbs is dead
|  | X 77339 The 5000 Page Thread: I'm going to pump the breaks on posting my genitals for a bit Pages: 1 2 3... 3974 3975 3976 Last post | Tip | 159018 | 1696429 |  | 21:14 Dec 4, 2024 Anderson Koopa
|  | Do you believe in any conspiracy theories? Pages: 1 2 3... 28 29 30 Last post | Donglepuss | 1176 | 43857 |  | 21:11 Dec 4, 2024 Teriyaki Hairpiece
|  | South Korea declares martial law Pages: 1 2 3... 7 8 9 Last post | Olewithmilk | 338 | 16539 |  | 20:55 Dec 4, 2024 Charlz Guybon
|  | Post Pictures of Weird and Wonderful Books Pages: 1 2 3... 50 51 52 Last post | Gutter Phoenix | 2059 | 195117 |  | 20:50 Dec 4, 2024 Desert Bus

Archives:
Powered by: vBulletin Version 2.2.9 (SABB-v2.24.12)
Copyright ©2000, 2001, Jelsoft Enterprises Limited.
Copyright ©2024, Jeffrey of YOSPOS
Privacy Policy